@@ -9,7 +9,7 @@ import numpy as np
 import nltk
 import editdistance
 from nltk.util import ngrams
-from dyslexic_readability import utils
+import  utils
 import readability_scores
 
 class DyslexicScores():
