@@ -1,7 +1,6 @@
 import nltk
-
 from nltk.tokenize import RegexpTokenizer
-from syllable.syllable import Encoder
+from syllable import Encoder
 
 TOKENIZER = RegexpTokenizer('(?u)\W+|\$[\d\.]+|\S+')
 SPECIAL_CHARS = ['.', ',', '!', '?']
